==> skill-service-1.13.3.jar: dbscript/all-resource.sql <==

use resources;
insert into resources(name,resource) values('userArticleRelation-common-skill-service-rmi','common.skill.service:9012');








use resources;
insert into resources(name,resource) values('userSkillRelation-common-skill-service-rmi','common.skill.service:9012');





use resources;
insert into resources(name,resource) values('userTaskRelation-skill-service-rmi','common.skill.service:9012');




use resources;
insert into resources(name,resource) values('sms-common-skill-service-rmi','common.skill.service:9011');





use resources;
insert into resources(name,resource) values('user-common-skill-service-rmi','common.skill.service:9012');





use resources;
insert into resources(name,resource) values('userClassRelation-common-skill-service-rmi','common.skill.service:9012');





use resources;
insert into resources(name,resource) values('comment-common-skill-service-rmi','common.skill.service:9012');





use resources;
insert into resources(name,resource) values('occupation-common-skill-service-rmi','common.skill.service:9012');





use resources;
insert into resources(name,resource) values('article-common-skill-service-rmi','common.skill.service:9012');





use resources;
insert into resources(name,resource) values('class-common-skill-service-rmi','common.skill.service:9012');






// 新加的
use resources;
insert into resources(name,resource) values('account-common-skill-service-rmi','common.skill.service:9012');
use resources;
insert into resources(name,resource) values('goods-common-skill-service-rmi','common.skill.service:9012');

use resources;
insert into resources(name,resource) values('order-common-skill-service-rmi','common.skill.service:9012');

use resources;
insert into resources(name,resource) values('servert-common-skill-service-rmi','common.skill.service:9012');

==> skill-service-14.0.0.jar: dbscript/all-resource.sql <==

use resources;
insert into resources(name,resource) values('userArticleRelation-common-skill-service-rmi','common.skill.service:9012');








use resources;
insert into resources(name,resource) values('userSkillRelation-common-skill-service-rmi','common.skill.service:9012');





use resources;
insert into resources(name,resource) values('userTaskRelation-skill-service-rmi','common.skill.service:9012');




use resources;
insert into resources(name,resource) values('sms-common-skill-service-rmi','common.skill.service:9011');





use resources;
insert into resources(name,resource) values('user-common-skill-service-rmi','common.skill.service:9012');





use resources;
insert into resources(name,resource) values('userClassRelation-common-skill-service-rmi','common.skill.service:9012');





use resources;
insert into resources(name,resource) values('comment-common-skill-service-rmi','common.skill.service:9012');





use resources;
insert into resources(name,resource) values('occupation-common-skill-service-rmi','common.skill.service:9012');





use resources;
insert into resources(name,resource) values('article-common-skill-service-rmi','common.skill.service:9012');





use resources;
insert into resources(name,resource) values('class-common-skill-service-rmi','common.skill.service:9012');






// 新加的
use resources;
insert into resources(name,resource) values('account-common-skill-service-rmi','common.skill.service:9012');
use resources;
insert into resources(name,resource) values('goods-common-skill-service-rmi','common.skill.service:9012');

use resources;
insert into resources(name,resource) values('order-common-skill-service-rmi','common.skill.service:9012');

use resources;
insert into resources(name,resource) values('servert-common-skill-service-rmi','common.skill.service:9012');


use resources;
insert into resources(name,resource) values('userScore-common-skill-service-rmi','common.skill.service:9012');



use resources;
insert into resources(name,resource) values('leaves-common-skill-service-rmi','common.skill.service:9012');


use resources;
insert into resources(name,resource) values('constant-common-skill-service-rmi','common.skill.service:9012');




use resources;
insert into resources(name,resource) values('card-common-skill-service-rmi','common.skill.service:9012');






use resources;
insert into resources(name,resource) values('clog-common-skill-service-rmi','common.skill.service:9012');






use resources;
insert into resources(name,resource) values('ctype-common-skill-service-rmi','common.skill.service:9012');
